@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 module Pathtest(tests) where
 import Test.HUnit
-import MissingH.Path
+import System.Path
 
 test_absNormPath =
     let f base p exp = TestLabel (show (base, p)) $ TestCase $ exp @=? absNormPath base p
