@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 module Strtest(tests) where
 import Test.HUnit
-import Data.String
+import Data.String.Utils
 import Test.HUnit.Utils
 import Text.Regex
 import Data.Char
